@@ -13,7 +13,6 @@ from algosdk import (
     util,
     wordlist,
 )
-
 from nacl.signing import SigningKey
 
 
@@ -780,3 +779,36 @@ class TestLogic(unittest.TestCase):
         )
         # txn StateProofPK; len; int 64; ==; gtxn 0 LastLog; len; int 10; ==; &&
         self.assertTrue(logic.check_program(program, None))
+
+
+class TestEncoding(unittest.TestCase):
+    """
+    Miscellaneous unit tests for functions in `encoding.py` not covered elsewhere
+    """
+
+    def test_encode_as_bytes(self):
+        bs = b"blahblah"
+        assert bs == encoding.encode_as_bytes(bs)
+
+        ba = bytearray("blueblue", "utf-8")
+        assert ba == encoding.encode_as_bytes(ba)
+
+        s = "i am a ho hum string"
+        assert s.encode() == encoding.encode_as_bytes(s)
+
+        i = 42
+        assert i.to_bytes(8, "big") == encoding.encode_as_bytes(i)
+
+        for bad_type in [
+            13.37,
+            type(self),
+            None,
+            {"hi": "there"},
+            ["hello", "goodbye"],
+        ]:
+            with pytest.raises(TypeError) as te:
+                encoding.encode_as_bytes(bad_type)
+
+            assert f"{bad_type} is not bytes, bytearray, str, or int" == str(
+                te.value
+            )
