@@ -1246,7 +1246,7 @@ class TestApplicationTransactions(unittest.TestCase):
             transaction.ApplicationCallTxn(
                 self.sender, params, 10, oc, app_args=[2, 3, 0]
             )  # ints work
-            with self.assertRaises(AssertionError):
+            with self.assertRaises(TypeError):
                 transaction.ApplicationCallTxn(
                     self.sender, params, 10, oc, app_args=[3.4]
                 )  # floats don't
@@ -1388,3 +1388,76 @@ class TestApplicationTransactions(unittest.TestCase):
         )
         self.assertEqual(i.dictify(), call.dictify())
         self.assertEqual(i, call)
+
+
+class TestBoxReference(unittest.TestCase):
+    def test_translate_box_references(self):
+        # Test case: reference input, foreign app array, caller app id, expected output
+        test_cases = [
+            ([], [], 9999, []),
+            (
+                [(100, "potato")],
+                [100],
+                9999,
+                [transaction.BoxReference(1, "potato".encode())],
+            ),
+            (
+                [(9999, "potato"), (0, "tomato")],
+                [100],
+                9999,
+                [
+                    transaction.BoxReference(0, "potato".encode()),
+                    transaction.BoxReference(0, "tomato".encode()),
+                ],
+            ),
+            # Self referencing its own app id in foreign array.
+            (
+                [(100, "potato")],
+                [100],
+                100,
+                [transaction.BoxReference(1, "potato".encode())],
+            ),
+            (
+                [(777, "tomato"), (888, "pomato")],
+                [100, 777, 888, 1000],
+                9999,
+                [
+                    transaction.BoxReference(2, "tomato".encode()),
+                    transaction.BoxReference(3, "pomato".encode()),
+                ],
+            ),
+        ]
+        for test_case in test_cases:
+            expected = test_case[3]
+            actual = transaction.BoxReference.translate_box_references(
+                test_case[0], test_case[1], test_case[2]
+            )
+
+            self.assertEqual(len(expected), len(actual))
+            for i, actual_refs in enumerate(actual):
+                self.assertEqual(expected[i], actual_refs)
+
+    def test_translate_invalid_box_references(self):
+        # Test case: reference input, foreign app array, error
+        test_cases_id_error = [
+            ([(1, "tomato")], [], error.InvalidForeignIndexError),
+            ([(-1, "tomato")], [1], error.InvalidForeignIndexError),
+            (
+                [(444, "pomato")],
+                [2, 3, 100, 888],
+                error.InvalidForeignIndexError,
+            ),
+            (
+                [(2, "tomato"), (444, "pomato")],
+                [2, 3, 100, 888],
+                error.InvalidForeignIndexError,
+            ),
+            ([("tomato", "tomato")], [1], TypeError),
+            ([(2, "zomato")], None, error.InvalidForeignIndexError),
+        ]
+
+        for test_case in test_cases_id_error:
+            with self.assertRaises(test_case[2]) as e:
+                transaction.BoxReference.translate_box_references(
+                    test_case[0], test_case[1], 9999
+                )
